@@ -30,16 +30,11 @@ class Respuesta(BaseModel):
         return mensaje
 
     @classmethod
-    def parse_xml(cls, respuesta_xml):
-        respuesta = etree.fromstring(respuesta_xml)  # noqa: S320
-        for element in respuesta.getchildren():
-            response = element.find('{http://www.praxis.com.mx/}respuesta')
-
-        mensaje_xml = etree.fromstring(bytes(response.text, encoding='cp850'))   # noqa: S320, E501
-        respuesta = mensaje_xml.find('respuesta')
+    def parse_xml(cls, respuesta_xml, category):
+        respuesta = respuesta_xml.find('respuesta')
 
         respuesta_data = {
-            'categoria': mensaje_xml.attrib['categoria'],
+            'categoria': category,
         }
 
         for sub_element in respuesta.getchildren():
